-- Timer-check if panels need attaching


-- Copies configtable to saved setting
function BeneCast.SnapTo:ApplyConfigTable()

	if not BeneCastSetup.SnapTo then
		return;
	end
	
	local addon = BeneCast.SnapTo[BeneCastSetup.SnapTo];
	if addon then
		for pfid, pf in pairs(BeneCastProfiles) do
			pf.SnapTo = {};		
			for unit, config in pairs(addon.configtable) do
				pf.SnapTo[unit] = {
					point = config.point,
					relativePoint = config.relativePoint,
					x = config.x,
					y = config.y,
				};
				if config.orientation then
					pf.SnapTo[unit].Orientation = config.orientation;
				else
					pf.SnapTo[unit].Orientation = pf.Orientation;
				end
			end
		end
	end

end

-- Generic function to attach panels based on saved setting
function BeneCast.SnapTo:SnapPanels()

	if not BeneCastSetup.SnapTo then
		return;
	end
	
	local addon = BeneCast.SnapTo[BeneCastSetup.SnapTo];
	if addon then
		local unitframe, profile, panelconf;
		for pfid, v in pairs(wv.Panels) do
			for unit in pairs(BeneCast.Constants.Targets) do
				if not v[unit] and not InCombatLockDown() then
					BeneCast.Panel:NewPanel(pfid,unit);
				end
				panel = v[unit];
				if panel then
					unitframe = addon:GetUnitFrame(unit);
					profile, panelconf = BeneCast:GetProfile(pfid, unit);
					if unitframe and panelconf then
						self:SnapPanel(unitframe,panel,panelconf);
					elseif not InCombatLockdown() then
						panel:Hide();
					end
				end
			end
		end
	end
	wv.AttachFrames = nil;
	
end

-- Function to attach a single panel to a unitframe
function BeneCast.SnapTo:SnapPanel(unitframe, panel, config)

	if unitframe == nil or panel == nil or config == nil then
		return;
	end
	
	-- Make sure we got nice rounded numbers
	config.x = math.floor(config.x + 0.5);
	config.y = math.floor(config.y + 0.5);
	
	if InCombatLockdown() then
		return;
	end
	
	UnregisterUnitWatch(panel);
	RegisterUnitWatch(panel);

	panel:SetParent(unitframe);
	panel:ClearAllPoints();
	local scaled_x = config.x / panel:GetEffectiveScale();
	local scaled_y = config.y / panel:GetEffectiveScale();
	panel:SetPoint(config.point, unitframe, config.relativePoint, scaled_x, scaled_y);
	panel:SetFrameLevel(unitframe:GetFrameLevel() + 1);
	-- Set up the correct level for the buttons on the panel
	local button = panel.next;
	while button do
		button:SetFrameLevel(panel:GetFrameLevel() + 1);
		button.Cooldown:SetFrameLevel(panel:GetFrameLevel() + 2);
	end
	wv.AttachedTargets[unit] = true;
	
	panel:OrientButtons();

end

-- Standard UI anchor positions
BeneCast.SnapTo.BeneCast = {
	name = 'Standard',
	configtable = {
		player       = { point = "TOPLEFT", frame = "PlayerFrame", relativePoint = "BOTTOM", x = -10, y = 30 },
		party1       = { point = "TOPLEFT", frame = "PartyMemberFrame1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "PartyMemberFrame2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "PartyMemberFrame3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "PartyMemberFrame4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "PartyMemberFrame1PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "PartyMemberFrame2PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "PartyMemberFrame3PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "PartyMemberFrame4PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "TargetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		targettarget = { point = "TOPLEFT", frame = "TargetofTargetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		focus        = { point = "TOPLEFT", frame = "PlayerFrame", relativePoint = "TOPRIGHT", x = 200, y = -20 },
	},
};

function BeneCast.SnapTo.BeneCast:GetUnitFrame(unit)
	if self.configtable[unit] then
		return getglobal(self.configtable[unit].frame);
	else
		return nil;
	end		
end

-- Perl anchor positions
BeneCast.SnapTo.Perl = {
	name = 'Perl',
	configtable = {
		player       = { point = "TOPLEFT", frame = "Perl_Player_Frame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "Perl_party1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "Perl_party2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "Perl_party3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "Perl_party4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "Perl_Party_Pet1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "Perl_Party_Pet2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "Perl_Party_Pet3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "Perl_Party_Pet4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "Perl_Target_Frame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		targettarget = { point = "TOPLEFT", frame = "Perl_TargetTarget_Frame", relativePoint = "BOTTOMLEFT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,
};

-- Perl anchor positions
BeneCast.SnapTo.Perl_Target = {
	name = 'Perl Classic',
	configtable = {
		player       = { point = "BOTTOMLEFT", frame = "Perl_Player_Frame", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		party1       = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame1", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		party2       = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame2", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		party3       = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame3", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		party4       = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame4", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame1_StatsFrame_PetHealthBar", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		partypet2    = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame2_StatsFrame_PetHealthBar", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		partypet3    = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame3_StatsFrame_PetHealthBar", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		partypet4    = { point = "BOTTOMLEFT", frame = "Perl_Party_MemberFrame4_StatsFrame_PetHealthBar", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		target       = { point = "BOTTOMLEFT", frame = "Perl_Target_Frame", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		focus        = { point = "BOTTOMLEFT", frame = "Perl_Focus_Frame", relativePoint = "TOPRIGHT", x = -5, y = -25 },
		targettarget = { point = "TOPLEFT", frame = "Perl_TargetTarget_Frame", relativePoint = "BOTTOMLEFT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,
};

-- Minigroup anchor positions
BeneCast.SnapTo.MiniGroup = {
	name = 'MiniGroup',
	configtable = {
		player       = { point = "TOPLEFT", frame = "MGParty_Member0", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "MGParty_Member1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "MGParty_Member2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "MGParty_Member3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "MGParty_Member4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "MGTarget_Frame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- Minigroup anchor positions
BeneCast.SnapTo.MiniGroup2 = {
	name = 'MiniGroup2',
	configtable = {
		player       = { point = "TOPLEFT", frame = "MGplayer", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "MGparty1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "MGparty2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "MGparty3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "MGparty4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "TOPLEFT", frame = "MGpet", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "MGpartypet1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "MGpartypet2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "MGpartypet3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "MGpartypet4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "MGtarget", relativePoint = "TOPRIGHT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- Nurfed anchor positions
BeneCast.SnapTo.Nurfed = {
	name = 'Nurfed',
	configtable = {
		player       = { point = "TOPLEFT", frame = "Nurfed_player", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "Nurfed_party1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "Nurfed_party2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "Nurfed_party3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "Nurfed_party4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "Nurfed_partypet1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "Nurfed_partypet2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "Nurfed_partypet3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "Nurfed_partypet4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "Nurfed_target", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		targettarget = { point = "TOPLEFT", frame = "Nurfed_targettargettarget", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		focus        = { point = "TOPLEFT", frame = "Nurfed_focus", relativePoint = "TOPRIGHT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- Noctambul anchor positions
BeneCast.SnapTo.NUF = {
	name = 'Noctambul',
	configtable = {
		player       = { point = "TOPLEFT", frame = "NUFPlayerFrame", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
		party1       = { point = "TOPLEFT", frame = "NUFPartyMemberFrame1", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
		party2       = { point = "TOPLEFT", frame = "NUFPartyMemberFrame2", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
		party3       = { point = "TOPLEFT", frame = "NUFPartyMemberFrame3", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
		party4       = { point = "TOPLEFT", frame = "NUFPartyMemberFrame4", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
		pet          = { point = "TOPLEFT", frame = "NUFPetFrame", relativePoint = "BOTTOMLEFT", x = 0, y = 0, orientation = "right" },
		partypet1    = { point = "TOPLEFT", frame = "NUFPartyPet1", relativePoint = "BOTTOMLEFT", x = 0, y = 0, orientation = "right" },
		partypet2    = { point = "TOPLEFT", frame = "NUFPartyPet2", relativePoint = "BOTTOMLEFT", x = 0, y = 0, orientation = "right" },
		partypet3    = { point = "TOPLEFT", frame = "NUFPartyPet3", relativePoint = "BOTTOMLEFT", x = 0, y = 0, orientation = "right" },
		partypet4    = { point = "TOPLEFT", frame = "NUFPartyPet4", relativePoint = "BOTTOMLEFT", x = 0, y = 0, orientation = "right" },
		target       = { point = "TOPLEFT", frame = "NUFTargetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
		targettarget = { point = "TOPLEFT", frame = "Dag_TargetTargetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0, orientation = "down" },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- SAE_PartyFrame 
BeneCast.SnapTo.SAE_PartyFrame = {
	name = 'SAE_PartyFrame', 
	configtable = {
		player       = { point = "TOPLEFT", frame = "PlayerFrame", relativePoint = "BOTTOM", x = -10, y = 30 }, 
		party1       = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame1", relativePoint = "TOPRIGHT", x = -5, y = -5 }, 
		party2       = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame2", relativePoint = "TOPRIGHT", x = -5, y = -5 }, 
		party3       = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame3", relativePoint = "TOPRIGHT", x = -5, y = -5 }, 
		party4       = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame4", relativePoint = "TOPRIGHT", x = -5, y = -5 }, 
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 }, 
		partypet1    = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame1PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 2 }, 
		partypet2    = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame2PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 2 }, 
		partypet3    = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame3PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 2 }, 
		partypet4    = { point = "TOPLEFT", frame = "SAE_PartyMemberFrame4PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 2 }, 
		target       = { point = "LEFT", frame = "TargetFrame", relativePoint = "RIGHT", x = -20, y = 7 }, 
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- Watchdog anchor positions
BeneCast.SnapTo.WatchDog = {
	name = 'WatchDog',
	configtable = {
		player       = { point = "TOPLEFT", frame = "WatchDogFrame_player", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "WatchDogFrame_party1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "WatchDogFrame_party2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "WatchDogFrame_party3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "WatchDogFrame_party4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "WatchDogFrame_partypet1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "WatchDogFrame_partypet2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "WatchDogFrame_partypet3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "WatchDogFrame_partypet4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "WatchDogFrame_target", relativePoint = "TOPRIGHT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- Discord anchor positions
BeneCast.SnapTo.DiscordUnitFrames = {
	name = 'Discord',
	configtable = {
		player       = { point = "TOPLEFT", frame = "DUF_PlayerFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "DUF_PartyFrame1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "DUF_PartyFrame2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "DUF_PartyFrame3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "DUF_PartyFrame4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "TOPLEFT", frame = "DUF_PetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "DUF_PartyPetFrame1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "DUF_PartyPetFrame2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "DUF_PartyPetFrame3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "DUF_PartyPetFrame4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "DUF_TargetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		targettarget = { point = "TOPLEFT", frame = "DUF_TargetOfTargetFrame", relativePoint = "TOPRIGHT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

--Sage anchor positions
BeneCast.SnapTo.Sage = {
	name = 'Sage',
	configtable = {
		player       = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = 0, y = -30 },
		party1       = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		party2       = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		party3       = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		party4       = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		pet          = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -110, y = -14 },
		partypet1    = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		partypet2    = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		partypet3    = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		partypet4    = { point = "TOPLEFT", relativePoint = "TOPRIGHT", x = -120, y = -14 },
		target       = { point = "TOPLEFT", relativePoint = "BOTTOMLEFT", x = 0, y = -20 },
		targettarget = { point = "TOPLEFT", relativePoint = "BOTTOMLEFT", x = 0, y = 0 },
		focus        = { point = "TOPLEFT", relativePoint = "BOTTOMLEFT", x = 0, y = 0 },
	},
};

function BeneCast.SnapTo.Sage:GetUnitFrame(unit)
	if self.configtable[unit] and SageFrame then
		for k, v in SageFrame.GetAll() do
    	if k == unit then
      	return v;
      end
    end
	end
end

-- ag_UnitFrames anchor positions
BeneCast_SnapTo.ag_UnitFrames = {
	name = 'ag_UnitFrames',
	configtable = {
		player       = { point = "TOPLEFT", frame = "aUFplayer", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "aUFpartyUnitButton1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "aUFpartyUnitButton2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "aUFpartyUnitButton3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "aUFpartyUnitButton4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "aUFpartypet1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "aUFpartypet2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "aUFpartypet3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "aUFpartypet4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "aUFtarget", relativePoint = "TOPRIGHT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};

-- XPerl anchor positions
BeneCast_SnapTo.XPerl  = {
	name = 'XPerl',
	configtable = {
		player       = { point = "TOPLEFT", frame = "XPerl_Player", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party1       = { point = "TOPLEFT", frame = "XPerl_party1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party2       = { point = "TOPLEFT", frame = "XPerl_party2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party3       = { point = "TOPLEFT", frame = "XPerl_party3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		party4       = { point = "TOPLEFT", frame = "XPerl_party4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		pet          = { point = "", frame = "", relativePoint = "", x = 0, y = 0 },
		partypet1    = { point = "TOPLEFT", frame = "XPerl_partypet1", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet2    = { point = "TOPLEFT", frame = "XPerl_partypet2", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet3    = { point = "TOPLEFT", frame = "XPerl_partypet3", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		partypet4    = { point = "TOPLEFT", frame = "XPerl_partypet4", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		target       = { point = "TOPLEFT", frame = "XPerl_Target", relativePoint = "TOPRIGHT", x = 0, y = 0 },
		targettarget = { point = "TOPLEFT", frame = "XPerl_TargetTarget", relativePoint = "BOTTOMLEFT", x = 0, y = 0 },
	},
	GetUnitFrame = BeneCast.SnapTo.BeneCast.GetUnitFrame,	
};
